==> libreoffice-4.0.3.3.tar.xz: libreoffice-4.0.3.3/test/source/util/xsearchable.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * Version: MPL 1.1 / GPLv3+ / LGPLv3+
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License or as specified alternatively below. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Major Contributor(s):
 * Copyright (C) 2012 Markus Mohrhard <markus.mohrhard@googlemail.com> (initial developer)
 *
 * All Rights Reserved.
 *
 * For minor contributions see the git repository.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 3 or later (the "GPLv3+"), or
 * the GNU Lesser General Public License Version 3 or later (the "LGPLv3+"),
 * in which case the provisions of the GPLv3+ or the LGPLv3+ are applicable
 * instead of those above.
 */

#include <com/sun/star/util/XSearchable.hpp>
#include <com/sun/star/util/XSearchDescriptor.hpp>
#include <com/sun/star/container/XIndexAccess.hpp>
#include "cppunit/extensions/HelperMacros.h"

#include <test/util/xsearchable.hxx>

using namespace com::sun::star::uno;

namespace apitest {

void XSearchable::testFindAll()
{
    uno::Reference< util::XSearchable > xSearchable(init(), UNO_QUERY_THROW);
    uno::Reference< util::XSearchDescriptor> xSearchDescr = xSearchable->createSearchDescriptor();
    xSearchDescr->setSearchString(maSearchString);

    uno::Reference< container::XIndexAccess > xIndex = xSearchable->findAll(xSearchDescr);
    CPPUNIT_ASSERT(xIndex.is());
    CPPUNIT_ASSERT(xIndex->getCount() == mnCount);
}

void XSearchable::testFindFirst()
{
    uno::Reference< util::XSearchable > xSearchable(init(), UNO_QUERY_THROW);
    uno::Reference< util::XSearchDescriptor> xSearchDescr = xSearchable->createSearchDescriptor();
    xSearchDescr->setSearchString(maSearchString);

    uno::Reference< uno::XInterface > xElement = xSearchable->findFirst(xSearchDescr);
    CPPUNIT_ASSERT(xElement.is());
}

void XSearchable::testFindNext()
{
    uno::Reference< util::XSearchable > xSearchable(init(), UNO_QUERY_THROW);
    uno::Reference< util::XSearchDescriptor> xSearchDescr = xSearchable->createSearchDescriptor();
    xSearchDescr->setSearchString(maSearchString);

    uno::Reference< uno::XInterface > xElement = xSearchable->findFirst(xSearchDescr);
    CPPUNIT_ASSERT(xElement.is());

    if (mnCount > 1)
    {
        uno::Reference< uno::XInterface > xElement2 = xSearchable->findNext(xElement, xSearchDescr);
        CPPUNIT_ASSERT(xElement2.is());
    }
}

XSearchable::~XSearchable()
{
}

}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_5.1.2.orig.tar.xz: libreoffice-5.1.2/test/source/util/xsearchable.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */

#include <com/sun/star/util/XSearchable.hpp>
#include <com/sun/star/util/XSearchDescriptor.hpp>
#include <com/sun/star/container/XIndexAccess.hpp>
#include "cppunit/extensions/HelperMacros.h"

#include <test/util/xsearchable.hxx>

using namespace css;
using namespace css::uno;

namespace apitest {

void XSearchable::testFindAll()
{
    uno::Reference< util::XSearchable > xSearchable(init(), UNO_QUERY_THROW);
    uno::Reference< util::XSearchDescriptor> xSearchDescr = xSearchable->createSearchDescriptor();
    xSearchDescr->setSearchString(maSearchString);

    uno::Reference< container::XIndexAccess > xIndex = xSearchable->findAll(xSearchDescr);
    CPPUNIT_ASSERT(xIndex.is());
    CPPUNIT_ASSERT(xIndex->getCount() == mnCount);
}

void XSearchable::testFindFirst()
{
    uno::Reference< util::XSearchable > xSearchable(init(), UNO_QUERY_THROW);
    uno::Reference< util::XSearchDescriptor> xSearchDescr = xSearchable->createSearchDescriptor();
    xSearchDescr->setSearchString(maSearchString);

    uno::Reference< uno::XInterface > xElement = xSearchable->findFirst(xSearchDescr);
    CPPUNIT_ASSERT(xElement.is());
}

void XSearchable::testFindNext()
{
    uno::Reference< util::XSearchable > xSearchable(init(), UNO_QUERY_THROW);
    uno::Reference< util::XSearchDescriptor> xSearchDescr = xSearchable->createSearchDescriptor();
    xSearchDescr->setSearchString(maSearchString);

    uno::Reference< uno::XInterface > xElement = xSearchable->findFirst(xSearchDescr);
    CPPUNIT_ASSERT(xElement.is());

    if (mnCount > 1)
    {
        uno::Reference< uno::XInterface > xElement2 = xSearchable->findNext(xElement, xSearchDescr);
        CPPUNIT_ASSERT(xElement2.is());
    }
}

XSearchable::~XSearchable()
{
}

}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
